/*******************************************************************************
 * Copyright (c) 2012 AGETO Service GmbH and others.
 * All rights reserved.
 *  
 * This program and the accompanying materials are made available under the 
 * terms of the Eclipse Distribution License v1.0 which accompanies this distribution,
 * and is available at https://www.eclipse.org/org/documents/edl-v10.html.
 *
 * Contributors:
 *     Gunnar Wagenknecht - initial API and implementation
 *******************************************************************************/
/*******************************************************************************
 * This is sample code. Use at your own risk. It comes WITHOUT any warranty.
 * Released to public domain. Please copy & paste as you wish.
 *
 * Initial Contribution: Gunnar Wagenknecht
 *******************************************************************************/
package sample_imp.service;

import java.util.Collection;

import org.eclipse.gyrex.cloud.environment.INodeEnvironment;
import org.osgi.service.component.ComponentContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import sample.service.GreetingService;

public class GreetingServiceComponent implements GreetingService {
	
	private static final Logger LOG = LoggerFactory.getLogger(GreetingServiceComponent.class);

	private GreetingService service;

	@Override
	public Collection<String> getGreetings() throws Exception {
		return getService().getGreetings();
	}

	@Override
	public void processGreetings() throws Exception {
		getService().processGreetings();
		//delegate to real service
	}

	@Override
	public void sayHello(String greeting) throws Exception {
		getService().sayHello(greeting);
		//delegate to real service
	}
	
	/*
	 * @param context
	 */
	public void activate(final ComponentContext context) {
		LOG.info("Service activated");
	}
	
	/*
	 * @param context
	 */
	public void deactivate(final ComponentContext context) {
		LOG.info("Service deactivated");
	}

	public GreetingService getService() {
		return service;
	}
	
	/**
	 * Sets the node environment.
	 * <p>
	 * The node environment will be used to read the node id. The node id
	 * uniquely identifies the node the system is running on. It is a
	 * <em>required</em> dependency as specified by <strong>
	 * <code>cardinality="1..1"</code> </strong> in the OSGi component
	 * definition file.
	 * </p>
	 * <p>
	 * This method will be called by the OSGi component runtime <em>when</em>
	 * the component is initialized as specified by <strong>
	 * <code>policy="static"</code> </strong> in the OSGi component definition
	 * file.
	 * </p>
	 * 
	 * <pre>
	 * &lt;reference bind="setEnvironment" cardinality="1..1" interface="org.eclipse.gyrex.cloud.environment.INodeEnvironment" name="INodeEnvironment" policy="static"/&gt;
	 * </pre>
	 * 
	 * @param environment
	 *            the environment to set
	 */
	public void setEnvironment(final INodeEnvironment environment) {
		// immediatly create greeting service
		service = new GreetingServiceImpl(environment.getNodeId());
	}
}
